@@ -1,14 +1,10 @@
 import unittest
 
 import easyglue
-
-from pyspark.context import SparkContext
-from awsglue.context import GlueContext
+from test.reader import ReaderTest
 
 
-class TestReadOthers(unittest.TestCase):
-
-    glue = GlueContext(SparkContext.getOrCreate())
+class TestReadOthers(ReaderTest):
 
     def test_dynamodb(self):
         data = self.glue.read().dynamodb("easyglue")
